==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SortIndicatorRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SortIndicatorRenderCompletedEventArgsDescription } from "./SortIndicatorRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
export let SortIndicatorRenderCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SortIndicatorRenderCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a == null) {
                SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SortIndicatorRenderCompletedEventArgsDescriptionMetadata.c(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.j(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            SortIndicatorRenderCompletedEventArgsDescriptionMetadata.b(a);
            a.aa("SortIndicatorRenderCompletedEventArgs", () => new SortIndicatorRenderCompletedEventArgsDescription());
            a.z("SortIndicatorRenderCompletedEventArgs", SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
        }
    }
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SortIndicatorRenderCompletedEventArgsDescriptionMetadata, 'SortIndicatorRenderCompletedEventArgsDescriptionMetadata');
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = null;
    return SortIndicatorRenderCompletedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SortIndicatorRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SortIndicatorRenderCompletedEventArgsDescription } from "./SortIndicatorRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
export let SortIndicatorRenderCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SortIndicatorRenderCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a == null) {
                SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SortIndicatorRenderCompletedEventArgsDescriptionMetadata.c(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            SortIndicatorRenderCompletedEventArgsDescriptionMetadata.b(a);
            a.ac("SortIndicatorRenderCompletedEventArgs", () => new SortIndicatorRenderCompletedEventArgsDescription());
            a.ab("SortIndicatorRenderCompletedEventArgs", SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a);
        }
    }
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SortIndicatorRenderCompletedEventArgsDescriptionMetadata, 'SortIndicatorRenderCompletedEventArgsDescriptionMetadata');
    SortIndicatorRenderCompletedEventArgsDescriptionMetadata.a = null;
    return SortIndicatorRenderCompletedEventArgsDescriptionMetadata;
})();
